@@ -7,5 +7,4 @@ admin.site.register(EveDoctrineSettings, DjangoSingletonModelAdmin)
 admin.site.register(EveDoctrineRole)
 admin.site.register(EveDoctrineManagerTag)
 admin.site.register(EveDoctrineCategory)
-admin.site.register(EveFitting)
-admin.site.register(EveSkillPlan)
+admin.site.register(EveFittingMarketRule)
