@@ -126,16 +126,19 @@ def skillcheck_utility(request):
         character__external_id=request.GET['external_id']).first()
     
     if not character_report:
-        return HttpResponse(status=500)
+        logger.info(f"No character report found for {external_id}")
+        return HttpResponse(status=400)
     else:
         character_report = character_report.get_report()
 
     if fitting:
-        if fitting.pk not in character_report['fittings']:
-            return HttpResponse(status=500)
-        
-        missing_skills = character_report['fittings'][fitting.pk].missing_skills
+        if str(fitting.pk) not in character_report['fittings']:
+            logger.info(f"Fitting {fitting.pk} not found in character report for {external_id}")
+            return HttpResponse(status=400)
+        fitting_id = str(fitting.pk)
+        fitting = character_report['fittings'][fitting_id]
 
+        missing_skills = fitting['missing_skills']
         if missing_skills:
             return JsonResponse({
                 'missing_skills': missing_skills
@@ -145,7 +148,7 @@ def skillcheck_utility(request):
 
     elif skillplan:
         if skillplan.pk not in character_report['skillplans']:
-            return HttpResponse(status=500)
+            return HttpResponse(status=400)
         missing_skills = character_report['skillplans'][skillplan.pk].missing_skills
         if missing_skills:
             return JsonResponse({
@@ -170,26 +173,31 @@ def skillcheck_utility(request):
 def hangarcheck_utility(request):
     if 'external_id' not in request.GET:
         return HttpResponse(status=400)
+    else:
+        external_id = request.GET['external_id']
     if not EveDoctrineSettings.objects.all().count() > 0:
-        return HttpResponse(status=500)
+        return HttpResponse(status=400)
     if not EveDoctrineSettings.get_instance().staging_structure:
-        return HttpResponse(status=500)
+        return HttpResponse(status=400)
     else:
         location_id = EveDoctrineSettings.get_instance().staging_structure.structure_id
 
     character_report = EveCharacterDoctrineReport.objects.filter(
         character__external_id=request.GET['external_id']).first()
     if not character_report:
+        logger.info(f"No character report for {external_id}")
         return HttpResponse(status=400)
 
     character_report = character_report.get_report()
 
     if 'fitting_id' in request.GET:
         fitting = EveFitting.objects.get(pk=request.GET['fitting_id'])
-        if fitting.pk not in character_report['fittings']:
+        fitting_id = str(fitting.pk)
+        if fitting_id not in character_report['fittings']:
             return HttpResponse(status=400)
         
-        if character_report['fittings'][fitting.pk]['in_hangar'] == True:
+        fitting = character_report['fittings'][fitting_id]
+        if fitting['in_hangar'] == True:
             return HttpResponse(status=204)
         else:
             return HttpResponse(status=404)
@@ -197,7 +205,7 @@ def hangarcheck_utility(request):
     if 'doctrine_id' in request.GET:
         doctrine = request.GET['doctrine_id']
         if doctrine not in character_report['doctrines']:
-            return HttpResponse(status=500)
+            return HttpResponse(status=400)
         
         if character_report['doctrines'][doctrine]['hangar_ready_fittings']:
             return HttpResponse(status=204)
@@ -209,5 +217,5 @@ def hangarcheck_utility(request):
 def get_fitting(request):
     if 'fitting_id' not in request.GET:
         return HttpResponse(status=400)
-    fitting = EveFitting.objects.get(pk=request.GET['fitting_id']).parse_fitting()
+    fitting = EveFitting.objects.get(pk=request.GET['fitting_id']).json
     return JsonResponse(fitting)
